==> SyL-0.9.0.tar.gz: SyL/include/lib/Xml/Rss/SyL_XmlRssClientResult.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_XmlRssClientResult.php,v 1.1 2007/03/17 13:53:07 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * HTTPꥯȷ̥饹
 */
require_once dirname(__FILE__) . '/../../Http/SyL_HttpClientResult.php';
/**
 * RSS꡼饹
 */
require_once 'SyL_XmlRssReader.php';

/**
 * RSSꥯȷ̥饹
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_XmlRssClientResult.php,v 1.1 2007/03/17 13:53:07 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_XmlRssClientResult extends SyL_HttpClientResult
{
    /**
     * RSS ꡼֥
     *
     * @access private
     * @var object
     */
    var $reader = null;

    /**
     * 󥹥ȥ饯
     * 
     * @access public
     * @param string ꥯȷ
     * @param string 饤ȥ󥳡
     * @param string RSSС
     */
    function SyL_XmlRssClientResult($data, $client_encode='', $rss_version='')
    {
        parent::SyL_HttpClientResult($data, $client_encode);

        $this->reader =& SyL_XmlRssReader::getInstance($this->body, $rss_version);
        if ($this->client_encode) {
            $this->reader->setClientEncode($this->client_encode);
        }
        $this->reader->parseXml();
    }

    /**
     * ꤷͥ
     *
     * @access public
     * @return mixed ꤷͥ
     */
    function getChannel($name)
    {
        return $this->reader->getChannel($name);
    }

    /**
     * ۿ
     *
     * @access public
     * @return array ۿ
     */
    function getItems()
    {
        return $this->reader->getItems();
    }
}

?>

==> SyL-0.14.4.tar.gz: SyL/include/lib/Xml/Rss/SyL_XmlRssClientResult.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_XmlRssClientResult.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * HTTPꥯȷ̥饹
 */
require_once dirname(__FILE__) . '/../../Http/SyL_HttpClientResult.php';
/**
 * RSS꡼饹
 */
require_once 'SyL_XmlRssReader.php';

/**
 * RSSꥯȷ̥饹
 *
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_XmlRssClientResult.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_XmlRssClientResult extends SyL_HttpClientResult
{
    /**
     * RSS ꡼֥
     *
     * @access private
     * @var object
     */
    var $reader = null;

    /**
     * 󥹥ȥ饯
     * 
     * @access public
     * @param string ꥯȷ
     * @param string 饤ȥ󥳡
     * @param string RSSС
     */
    function SyL_XmlRssClientResult($data, $client_encode='', $rss_version='')
    {
        parent::SyL_HttpClientResult($data, $client_encode);
        $this->reader =& SyL_XmlRssReader::getObject($this->body, $rss_version);
        if ($this->client_encode) {
            $this->reader->setClientEncode($this->client_encode);
        }
        $this->reader->parseXml();
    }

    /**
     * ꤷͥ
     *
     * @access public
     * @return mixed ꤷͥ
     */
    function getChannel($name)
    {
        return $this->reader->getChannel($name);
    }

    /**
     * ꤷͥ°
     *
     * @access public
     * @param string ̾
     * @param string ǥ̾
     * @return array ꤷͥ°
     */
    function getChannelAttr($name, $subname=null)
    {
        return $this->reader->getChannelAttr($name, $subname);
    }

    /**
     * ۿ
     *
     * @access public
     * @return array ۿ
     */
    function getItems()
    {
        return $this->reader->getItems();
    }

    /**
     * ۿ°
     *
     * @access public
     * @param int 
     * @param string ̾
     * @param string ǥ̾
     * @return array ۿ°
     */
    function getItemAttr($index, $name, $subname=null)
    {
        return $this->reader->getItemAttr($index, $name, $subname);
    }

    /**
     * ۿ
     *
     * @access public
     * @return int ۿ
     */
    function getItemCount()
    {
        return $this->reader->getItemCount();
    }
}

?>
